diff --git a/source/distro/changelog.txt b/source/distro/changelog.txt
index ca5925a..5677558 100644
--- a/source/distro/changelog.txt
+++ b/source/distro/changelog.txt
@@ -4,19 +4,22 @@ Changelog for Writer2LaTeX version 1.4 -> 1.6
Items marked with * are work in progress
-[all] The position of message boxes has changed from (0,0) to (200,100)
-
-[w2l] Implementation detail: The dialog library W4LDialogs are now merged into W2LDialogs2. This avoids conflicts with
- the old Writer4LaTeX extension if this happens to be installed.
-
-[all] *Document the use of soffice --headless --convert-to
+[all] *Document the use of soffice --headless --convert-to
[w2x] *Added EPUB 3 as export format and changed the toolbar to export to EPUB 3
+[all] The position of message boxes has changed from (0,0) to (200,100)
+
+[w2l] Implementation detail: The dialog library W4LDialogs is now merged into W2LDialogs2. This avoids conflicts with
+ the old Writer4LaTeX extension if this happens to be installed.
+
[all] Fixed typo in export dialogs: The text on the help button was in danish.
[w2x] New boolean option embed_img (default false). If set to true, the binary contents of img elements are included
directly on the src attribute as base64.
+
+[w2l] The bibliography configuration is slightly modified: The options to convert Zotero or JabRef citations are now
+ only available if the option to use external BibTeX files is selected
[w2l] Added new BibTeX dialog to insert a bibliographic reference to a BibTeX file. The BibTeX files are located as
defined in the configuration, and the reference is inserted as an ordinary reference mark.
diff --git a/source/java/org/openoffice/da/comp/writer2latex/BibliographyDialog.java b/source/java/org/openoffice/da/comp/writer2latex/BibliographyDialog.java
index 4d9f078..05f9148 100644
--- a/source/java/org/openoffice/da/comp/writer2latex/BibliographyDialog.java
+++ b/source/java/org/openoffice/da/comp/writer2latex/BibliographyDialog.java
@@ -16,11 +16,11 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston,
* MA 02111-1307 USA
*
- * Copyright: 2002-2014 by Henrik Just
+ * Copyright: 2002-2015 by Henrik Just
*
* All Rights Reserved.
*
- * Version 1.6 (2014-10-29)
+ * Version 1.6 (2015-02-18)
*
*/
@@ -254,16 +254,18 @@ public final class BibliographyDialog
}
private void enableBibTeXSettings(DialogAccess dlg) {
- boolean bConvertZoteroJabRef = dlg.getCheckBoxStateAsBoolean("ConvertZoteroCitations")
+ boolean bEnableSettings = dlg.getCheckBoxStateAsBoolean("UseExternalBibTeXFiles");
+ boolean bEnableOriginalCitations = dlg.getCheckBoxStateAsBoolean("ConvertZoteroCitations")
|| dlg.getCheckBoxStateAsBoolean("ConvertJabRefCitations");
- boolean bEnableLocation = dlg.getCheckBoxStateAsBoolean("UseExternalBibTeXFiles") || bConvertZoteroJabRef;
boolean bEnableDir = dlg.getListBoxSelectedItem("BibTeXLocation")<2;
- dlg.setControlEnabled("IncludeOriginalCitations", bConvertZoteroJabRef);
- dlg.setControlEnabled("BibTeXLocationLabel", bEnableLocation);
- dlg.setControlEnabled("BibTeXLocation", bEnableLocation);
- dlg.setControlEnabled("BibTeXDirLabel", bEnableLocation && bEnableDir);
- dlg.setControlEnabled("BibTeXDir", bEnableLocation && bEnableDir);
- dlg.setControlEnabled("BibTeXDirButton", bEnableLocation && bEnableDir);
+ dlg.setControlEnabled("BibTeXLocationLabel", bEnableSettings);
+ dlg.setControlEnabled("BibTeXLocation", bEnableSettings);
+ dlg.setControlEnabled("BibTeXDirLabel", bEnableSettings && bEnableDir);
+ dlg.setControlEnabled("BibTeXDir", bEnableSettings && bEnableDir);
+ dlg.setControlEnabled("BibTeXDirButton", bEnableSettings && bEnableDir);
+ dlg.setControlEnabled("ConvertZoteroCitations", bEnableSettings);
+ dlg.setControlEnabled("ConvertJabRefCitations", bEnableSettings);
+ dlg.setControlEnabled("IncludeOriginalCitations", bEnableSettings && bEnableOriginalCitations);
}
private String getDocumentDirURL() {
diff --git a/source/java/org/openoffice/da/comp/writer2latex/LaTeXUNOPublisher.java b/source/java/org/openoffice/da/comp/writer2latex/LaTeXUNOPublisher.java
index a437227..c7b8059 100644
--- a/source/java/org/openoffice/da/comp/writer2latex/LaTeXUNOPublisher.java
+++ b/source/java/org/openoffice/da/comp/writer2latex/LaTeXUNOPublisher.java
@@ -20,7 +20,7 @@
*
* All Rights Reserved.
*
- * Version 1.6 (2015-02-16)
+ * Version 1.6 (2015-02-18)
*
*/
package org.openoffice.da.comp.writer2latex;
@@ -105,14 +105,14 @@ public class LaTeXUNOPublisher extends UNOPublisher {
XPropertySet xProps = (XPropertySet) UnoRuntime.queryInterface(XPropertySet.class,view);
String sBibTeXFiles = getFileList(XPropertySetHelper.getPropertyValueAsShort(xProps, "BibTeXLocation"),
XPropertySetHelper.getPropertyValueAsString(xProps, "BibTeXDir"));
- if (XPropertySetHelper.getPropertyValueAsBoolean(xProps, "ConvertZoteroCitations")) {
- filterHelper.put("zotero_bibtex_files", sBibTeXFiles);
- }
- if (XPropertySetHelper.getPropertyValueAsBoolean(xProps, "ConvertJabRefCitations")) {
- filterHelper.put("jabref_bibtex_files", sBibTeXFiles);
- }
if (XPropertySetHelper.getPropertyValueAsBoolean(xProps, "UseExternalBibTeXFiles")) {
filterHelper.put("external_bibtex_files", sBibTeXFiles);
+ if (XPropertySetHelper.getPropertyValueAsBoolean(xProps, "ConvertZoteroCitations")) {
+ filterHelper.put("zotero_bibtex_files", sBibTeXFiles);
+ }
+ if (XPropertySetHelper.getPropertyValueAsBoolean(xProps, "ConvertJabRefCitations")) {
+ filterHelper.put("jabref_bibtex_files", sBibTeXFiles);
+ }
}
filterHelper.put("include_original_citations",
Boolean.toString(XPropertySetHelper.getPropertyValueAsBoolean(xProps, "IncludeOriginalCitations")));
diff --git a/source/java/org/openoffice/da/comp/writer2latex/Writer2LaTeX.java b/source/java/org/openoffice/da/comp/writer2latex/Writer2LaTeX.java
index e48e144..8634685 100644
--- a/source/java/org/openoffice/da/comp/writer2latex/Writer2LaTeX.java
+++ b/source/java/org/openoffice/da/comp/writer2latex/Writer2LaTeX.java
@@ -20,20 +20,25 @@
*
* All Rights Reserved.
*
- * Version 1.6 (2015-02-09)
+ * Version 1.6 (2015-02-18)
*
*/
package org.openoffice.da.comp.writer2latex;
+import com.sun.star.beans.XPropertySet;
import com.sun.star.frame.XFrame;
import com.sun.star.lib.uno.helper.WeakBase;
import com.sun.star.ui.dialogs.ExecutableDialogResults;
import com.sun.star.ui.dialogs.XExecutableDialog;
+import com.sun.star.uno.Exception;
import com.sun.star.uno.UnoRuntime;
import com.sun.star.uno.XComponentContext;
import org.openoffice.da.comp.w2lcommon.filter.UNOPublisher.TargetFormat;
+import org.openoffice.da.comp.w2lcommon.helper.MessageBox;
+import org.openoffice.da.comp.w2lcommon.helper.RegistryHelper;
+import org.openoffice.da.comp.w2lcommon.helper.XPropertySetHelper;
/** This class implements the ui (dispatch) commands provided by the Writer2LaTeX toolbar.
* The actual processing is done by the core classes UNOPublisher,
@@ -175,28 +180,48 @@ public final class Writer2LaTeX extends WeakBase
}
private void insertBibTeX() {
- createUNOPublisher();
- if (unoPublisher.documentSaved()) {
- // Execute the BibTeX dialog
- try {
- // The dialog needs the current frame and the path to the BibTeX directory
- Object[] args = new Object[2];
- args[0] = m_xFrame;
- args[1] = unoPublisher.getBibTeXDirectory().getPath();
- Object dialog = m_xContext.getServiceManager()
- .createInstanceWithArgumentsAndContext(
- "org.openoffice.da.writer2latex.BibTeXDialog", args, m_xContext);
- XExecutableDialog xDialog = (XExecutableDialog)
- UnoRuntime.queryInterface(XExecutableDialog.class, dialog);
- if (xDialog.execute()==ExecutableDialogResults.OK) {
- // Closed with the close button
- }
- }
- catch (com.sun.star.uno.Exception e) {
- }
- }
+ if (useExternalBibTeXFiles()) {
+ createUNOPublisher();
+ if (unoPublisher.documentSaved()) {
+ // Execute the BibTeX dialog
+ try {
+ // The dialog needs the current frame and the path to the BibTeX directory
+ Object[] args = new Object[2];
+ args[0] = m_xFrame;
+ args[1] = unoPublisher.getBibTeXDirectory().getPath();
+ Object dialog = m_xContext.getServiceManager()
+ .createInstanceWithArgumentsAndContext(
+ "org.openoffice.da.writer2latex.BibTeXDialog", args, m_xContext);
+ XExecutableDialog xDialog = (XExecutableDialog)
+ UnoRuntime.queryInterface(XExecutableDialog.class, dialog);
+ if (xDialog.execute()==ExecutableDialogResults.OK) {
+ // Closed with the close button
+ }
+ }
+ catch (com.sun.star.uno.Exception e) {
+ }
+ }
+ }
+ else {
+ MessageBox msgBox = new MessageBox(m_xContext, m_xFrame);
+ msgBox.showMessage("Writer2LaTeX","Writer2LaTeX is not configured to use external BibTeX files for citations");
+ }
}
+ private boolean useExternalBibTeXFiles() {
+ // Get the BibTeX settings from the registry
+ RegistryHelper registry = new RegistryHelper(m_xContext);
+ Object view;
+ try {
+ view = registry.getRegistryView(BibliographyDialog.REGISTRY_PATH, false);
+ } catch (Exception e) {
+ // Failed to get registry settings
+ return false;
+ }
+ XPropertySet xProps = (XPropertySet) UnoRuntime.queryInterface(XPropertySet.class,view);
+ return XPropertySetHelper.getPropertyValueAsBoolean(xProps, "UseExternalBibTeXFiles");
+ }
+
private void createUNOPublisher() {
if (unoPublisher==null) {
unoPublisher = new LaTeXUNOPublisher(m_xContext,m_xFrame,"Writer2LaTeX");
diff --git a/source/oxt/writer2latex/W2LDialogs2/BibTeXEntry.xdl b/source/oxt/writer2latex/W2LDialogs2/BibTeXEntry.xdl
index 6ff1747..180f452 100644
--- a/source/oxt/writer2latex/W2LDialogs2/BibTeXEntry.xdl
+++ b/source/oxt/writer2latex/W2LDialogs2/BibTeXEntry.xdl
@@ -16,14 +16,17 @@
+
+
+
-
+
-
-
+
+
-
-
+
+
\ No newline at end of file
diff --git a/source/oxt/writer2latex/W2LDialogs2/Bibliography.xdl b/source/oxt/writer2latex/W2LDialogs2/Bibliography.xdl
index d629ccf..a08cc38 100644
--- a/source/oxt/writer2latex/W2LDialogs2/Bibliography.xdl
+++ b/source/oxt/writer2latex/W2LDialogs2/Bibliography.xdl
@@ -2,27 +2,14 @@
-
-
-
-
-
-
+
+
+
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
@@ -30,8 +17,31 @@
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
\ No newline at end of file
diff --git a/source/oxt/writer2latex/help/en/org.openoffice.da.writer2latex.oxt/bibliography.xhp b/source/oxt/writer2latex/help/en/org.openoffice.da.writer2latex.oxt/bibliography.xhp
index 8153364..7b9e207 100644
--- a/source/oxt/writer2latex/help/en/org.openoffice.da.writer2latex.oxt/bibliography.xhp
+++ b/source/oxt/writer2latex/help/en/org.openoffice.da.writer2latex.oxt/bibliography.xhp
@@ -9,84 +9,67 @@
Configuration of bibliography
- On this page you can define the interaction between Writer2LaTeX and
- external bibliographic tools.
+ On this page you can configure the use of BibTeX as bibliography
+ database in %PRODUCTNAME Writer.
Select Tools - Options - %PRODUCTNAME Writer - Writer2LaTeX toolbar - Bibliography
- Citations and BibTeX files
- There are several ways to handle bibliographic references in %PRODUCTNAME Writer.
- If you use the standard bibliographic tool provided by %PRODUCTNAME, Writer2LaTeX can convert the references to BibTeX if you
- choose to do so in the export dialog. In this case you should not make any settings on this page.
-
- You may also use the Writer2LaTeX toolbar to insert bibliographic references from
- BibTeX files. In this case Writer2LaTeX can be configured to use the original BibTeX files.
- To use this feature, you have to define the location of your BibTeX files.
-
- You may also use other tools such as Zotero or JabRef to handle your citations.
- If you want to use BibTeX to format references inserted by these tools, Writer2LaTeX can convert them for you. In this case
- you have to define the location of the BibTeX files produced by Zotero or JabRef.
+ Bibliography database
+ %PRODUCTNAME Writer comes with a standard bibliography database.
+ Citations can be created from the content of the database.
+ The Writer2LaTeX toolbar provides an alternative solution: On this page you can configure the use of BibTeX
+ as bibliography database.
+
+
+
+
+
+ The standard bibliographic tool in Writer can
+ be used to insert citations from the bibliography database
+
+
+ The Writer2LaTeX toolbar can be used to insert
+ citations from BibTeX files
+
+
+ JabRef
+ is an open source bibliography reference manager using BibTeX as native file format.
+
+ You can use JabRef to edit your BibTeX files.
+ In addition JabRef provides a plugin
+ which permits you to insert citations from JabRef in your %PRODUCTNAME Writer document
+ using a selection of citation schemes. You should use version 0.8.999 beta or later of the plugin.
+
+
+ Zotero
+ is a free, easy-to-use tool to help you collect, organize, cite, and share your research sources.
+ Zotero provides a plugin for %PRODUCTNAME which permits you to insert citations from Zotero in your
+ %PRODUCTNAME Writer document using a selection of citation schemes.
+
+
+ In the first case, you should not make any settings to this page.
+ Writer2LaTeX can optionally convert to and format your citations with BibTeX if you choose so in the export
+ dialog.
+
+ In the other cases it makes sense to use the original BibTeX files
+ in the LaTeX document.
+
+
- Use external BibTeX files for ordinary citations
- Check this if you use the Writer2LaTeX toolbar to insert bibliographic references from BibTeX files.
- This enables you to use the original BibTeX files in the LaTeX document rather than converting the
+ Use BibTeX as bibliography database
+ Check this to use the original BibTeX files in the LaTeX document rather than converting the
inserted references back into BibTeX.Check this if your citatations are inserted from BibTeX file(s)
-
- Convert Zotero citations
- Zotero
- is a free, easy-to-use tool to help you collect, organize, cite, and share your research sources.
- Zotero provides a plugin for %PRODUCTNAME which permits you to insert citations from Zotero in your %PRODUCTNAME Writer document
- using a selection of citation schemes.
- Check this if you want to convert Zotero citations to LaTeX.
- This enables you to format the citations using a BibTeX style of your choice.
- Also, the bibliography created by Zotero will be replaced with a BibTeX-generated bibliography.
- If you do not check this option, the original
- citation text inserted by Zotero will be used.
- Exporting your Zotero database to BibTeX
- To use this feature you must export your Zotero database to the specified
- folder.
- The Writer2LaTeX distribution contains a folder named Zotero,
- which contains a file called BibTeX-Writer2LaTeX.js. This file must be added to Zotero to provide a suitable
- BibTeX export: In Zotero, choose Preferences - Advanced and click Show Data Directory.
- Open the subfolder Translators, and copy BibTeX-Writer2LaTeX.js to this location.
- Finally restart Firefox.
- You can now export your Zotero database: In Zotero, select
- Export Library, and choose BibTeX (Writer2LaTeX) (not BibTeX).
- Save the file in the folder, you have defined.
- Check this to convert Zotero citations to LaTeX
-
-
- Convert JabRef citations
- JabRef
- is an open source bibliography reference manager using BibTeX as native file format.
- Zotero provides a plugin
- which permits you to insert citations from JabRef in your %PRODUCTNAME Writer document
- using a selection of citation schemes. You should use version 0.8.999 beta or later of the plugin.
- Check this if you want to convert JabRef citations to LaTeX.
- This enables you to format the citations using a BibTeX style of your choice.
- Also, the bibliography created by JabRef will be replaced with a BibTeX-generated bibliography.
- If you do not check this option, the original
- citation text inserted by JabRef will be used.
- Check this to convert JabRef citations to LaTeX
-
-
- Include original citations as comments
- Check this if you want to include the original citations produced by Zotero or
- JabRef as comments in the LaTeX source. This has no effect on the final result but might be helpful if you edit the LaTeX source.
- Check this to include the citations inserted by Zotero or JabRef as comments in the LaTeX source.
-
-
BibTeX locationWriter2LaTeX will look for BibTeX files in the location you define.In central folder: Select this option if you keep all your
- BibTeX files in a central location (this is usually recommended).
+ BibTeX files in a central location.In subfolder of document folder: Select this option if you
@@ -110,6 +93,42 @@
Click to select the path to the folder containing the BibTeX files
+
+ Convert Zotero citations
+ Check this if you want to convert Zotero citations to LaTeX.
+ This enables you to format the citations using a BibTeX style of your choice.
+ Also, the bibliography created by Zotero will be replaced with a BibTeX-generated bibliography.
+ If you do not check this option, the original
+ citation text inserted by Zotero will be used.
+ Exporting your Zotero database to BibTeX
+ To use this feature you must export your Zotero database to the specified
+ folder.
+ The Writer2LaTeX distribution contains a folder named Zotero,
+ which contains a file called BibTeX-Writer2LaTeX.js. This file must be added to Zotero to provide a suitable
+ BibTeX export: In Zotero, choose Preferences - Advanced and click Show Data Directory.
+ Open the subfolder Translators, and copy BibTeX-Writer2LaTeX.js to this location.
+ Finally restart Firefox.
+ You can now export your Zotero database: In Zotero, select
+ Export Library, and choose BibTeX (Writer2LaTeX) (not BibTeX).
+ Save the file in the folder, you have defined.
+ Check this to convert Zotero citations to LaTeX
+
+
+ Convert JabRef citations
+ Check this if you want to convert JabRef citations to LaTeX.
+ This enables you to format the citations using a BibTeX style of your choice.
+ Also, the bibliography created by JabRef will be replaced with a BibTeX-generated bibliography.
+ If you do not check this option, the original
+ citation text inserted by JabRef will be used.
+ Check this to convert JabRef citations to LaTeX
+
+
+ Include original citations as comments
+ Check this if you want to include the original citations produced by Zotero or
+ JabRef as comments in the LaTeX source. This has no effect on the final result but might be helpful if you edit the LaTeX source.
+ Check this to include the citations inserted by Zotero or JabRef as comments in the LaTeX source.
+
+
Natbib
diff --git a/source/oxt/writer2latex/help/en/org.openoffice.da.writer2latex.oxt/bibtex.xhp b/source/oxt/writer2latex/help/en/org.openoffice.da.writer2latex.oxt/bibtex.xhp
index fa42c62..3033d13 100644
--- a/source/oxt/writer2latex/help/en/org.openoffice.da.writer2latex.oxt/bibtex.xhp
+++ b/source/oxt/writer2latex/help/en/org.openoffice.da.writer2latex.oxt/bibtex.xhp
@@ -43,13 +43,13 @@
the currently selected entry.Click to insert a reference to the current entry
-
- Refresh
- Click this button to reload the BibTeX
- files and update all references. You should do this if you have edited a BibTeX file. This will ensure that
+
+ Update references
+ Click this to update all bibliographic references in the document.
+ You should do this if you have edited a BibTeX file. This will ensure that
the content of all references is in sync with the current content of the BibTeX files.
- Writer2LaTeX will display an message to confirm the result.
- Click to refresh the dialog and all references
+ Writer2LaTeX will display a message to confirm the result.
+ Click to update the content of all referencesClose
@@ -69,5 +69,10 @@
an error message is displayed.
Click to edit the current file in your BibTeX editor
+
+ Reload
+ Click this button to reload the BibTeX files in the dialog.
+ Click to reload the BibTeX files
+
\ No newline at end of file
diff --git a/source/java/org/openoffice/da/comp/writer2latex/BibTeXDialog.java b/source/java/org/openoffice/da/comp/writer2latex/BibTeXDialog.java
index d311f3b..8f5e630 100644
--- a/source/java/org/openoffice/da/comp/writer2latex/BibTeXDialog.java
+++ b/source/java/org/openoffice/da/comp/writer2latex/BibTeXDialog.java
@@ -20,7 +20,7 @@
*
* All Rights Reserved.
*
- * Version 1.6 (2015-02-15)
+ * Version 1.6 (2015-02-18)
*
*/
@@ -131,7 +131,7 @@ public class BibTeXDialog extends DialogBase implements com.sun.star.lang.XIniti
}
@Override public void initialize() {
- refreshDialog(null);
+ reload(null);
}
@Override public void endDialog() {
@@ -148,10 +148,6 @@ public class BibTeXDialog extends DialogBase implements com.sun.star.lang.XIniti
// The user has selected another BibTeX entry
entryChange();
}
- else if (sMethod.equals("InsertReference")) {
- // Insert a reference to the current BibTeX entry
- insertReference();
- }
else if (sMethod.equals("New")) {
// Create a new BibTeX file
newFile();
@@ -160,23 +156,30 @@ public class BibTeXDialog extends DialogBase implements com.sun.star.lang.XIniti
// Edit the current BibTeX file
edit();
}
- else if (sMethod.equals("Refresh")) {
- // Refresh the dialog and update all bibliographic references
- refreshDialog(null);
- refreshReferences();
+ else if (sMethod.equals("Reload")) {
+ // Reload the BibTeX files in the dialog
+ reload(null);
+ }
+ else if (sMethod.equals("InsertReference")) {
+ // Insert a reference to the current BibTeX entry
+ insertReference();
+ }
+ else if (sMethod.equals("Update")) {
+ // Update all reference in the document
+ update();
}
return true;
}
@Override public String[] getSupportedMethodNames() {
- String[] sNames = { "FileChange", "EntryChange", "InsertReference", "Edit", "Refresh" };
+ String[] sNames = { "FileChange", "EntryChange", "New", "Edit", "Reload", "InsertReference", "Update" };
return sNames;
}
// **** Implement the UI functions
// (Re)load the list of BibTeX files
- private void refreshDialog(String sSelectedFileName) {
+ private void reload(String sSelectedFileName) {
String sFile = null;
if (sSelectedFileName!=null) {
// Select a new file name
@@ -217,6 +220,7 @@ public class BibTeXDialog extends DialogBase implements com.sun.star.lang.XIniti
setControlEnabled("Entry",true);
setControlEnabled("Edit",true);
setControlEnabled("Insert",true);
+ setControlEnabled("Update",true);
fileChange();
@@ -231,6 +235,7 @@ public class BibTeXDialog extends DialogBase implements com.sun.star.lang.XIniti
setControlEnabled("Entry",false);
setControlEnabled("Edit",false);
setControlEnabled("Insert",false);
+ setControlEnabled("Update",false);
setLabelText("EntryInformation","No BibTeX files were found");
}
@@ -251,6 +256,7 @@ public class BibTeXDialog extends DialogBase implements com.sun.star.lang.XIniti
} catch (IOException e) {
currentFile = null;
} catch (ParseException e) {
+ System.out.println(e.getMessage());
currentFile = null;
}
@@ -322,15 +328,21 @@ public class BibTeXDialog extends DialogBase implements com.sun.star.lang.XIniti
private void newFile() {
String sFileName = getFileName();
if (sFileName!=null) {
- File file = new File(bibTeXDirectory,sFileName);
- try {
- if (!file.createNewFile() && xFrame!=null) {
- MessageBox msgBox = new MessageBox(xContext, xFrame);
- msgBox.showMessage("Writer2LaTeX","The file "+sFileName+" already exists");
- }
- refreshDialog(sFileName);
- } catch (IOException e) {
- }
+ if (!sFileName.equals(".bib")) {
+ File file = new File(bibTeXDirectory,sFileName);
+ try {
+ if (!file.createNewFile() && xFrame!=null) {
+ MessageBox msgBox = new MessageBox(xContext, xFrame);
+ msgBox.showMessage("Writer2LaTeX","The file "+sFileName+" already exists");
+ }
+ reload(sFileName);
+ } catch (IOException e) {
+ }
+ }
+ else if (xFrame!=null) {
+ MessageBox msgBox = new MessageBox(xContext, xFrame);
+ msgBox.showMessage("Writer2LaTeX","The file name is empty");
+ }
}
}
@@ -412,8 +424,8 @@ public class BibTeXDialog extends DialogBase implements com.sun.star.lang.XIniti
}
}
- // Refresh all bibliographic fields in the document
- private void refreshReferences() {
+ // Update all bibliographic fields in the document
+ private void update() {
if (xFrame!=null) {
BibTeXReader[] readers = parseAllBibTeXFiles();